/**
 * Copyright (c) 2003,2008 Craig Setera and others.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     Craig Setera (EclipseME) - Initial implementation
 *     Diego Sandin (Motorola)  - Refactoring package name to follow
 *                                eclipse standards
 *     Diego Sandin (Motorola)  - Re-enabling Preprocessor code  
 *     David Marques (Motorola) - Fixing adding builders to nature.                         
 */
package org.eclipse.mtj.internal.core.build.preprocessor;

import org.eclipse.core.resources.IProjectNature;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.NullProgressMonitor;
import org.eclipse.jdt.core.JavaCore;
import org.eclipse.mtj.core.project.MTJNature;
import org.eclipse.mtj.internal.core.IMTJCoreConstants;
import org.eclipse.mtj.internal.core.build.BuildSpecManipulator;

/**
 * <p>
 * Project nature for J2ME projects that preproces their resources.
 * </p>
 * <b>Note:</b> This class/interface is part of an interim API that is still
 * under development and expected to change before reaching stability. It is
 * being made available at this early stage to solicit feedback from pioneering
 * adopters on the understanding that any code that uses this API will almost
 * certainly be broken as the API evolves.
 * 
 * @author Craig Setera
 * @see IProjectNature
 */
public class PreprocessingNature extends MTJNature {

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.mtj.core.nature.AbstractNature#configure()
     */
    public void configure() throws CoreException {
    	BuildSpecManipulator manipulator = new BuildSpecManipulator(getProject());
        manipulator.addBuilderBefore(IMTJCoreConstants.J2ME_VALIDATOR_ID,
                IMTJCoreConstants.J2ME_PREPROCESSOR_ID, null);
        manipulator.commitChanges(new NullProgressMonitor());
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.mtj.core.project.MTJNature#deconfigure()
     */
    public void deconfigure() throws CoreException {
    	BuildSpecManipulator manipulator = new BuildSpecManipulator(getProject());
        manipulator.removeBuilder(IMTJCoreConstants.J2ME_PREPROCESSOR_ID);
        manipulator.commitChanges(new NullProgressMonitor());
    }
}
